@@ -6,6 +6,8 @@ import click
 from pathlib import Path
 from future.moves import subprocess
 
+from mldock.config_managers.cli import \
+    CliConfigureManager
 import mldock.api.predict as predict_request
 from mldock.terminal import \
     ChoiceWithNumbers, style_dropdown, style_2_level_detail
@@ -16,6 +18,7 @@ from mldock.api.local import \
 
 click.disable_unicode_literals_warning = True
 logger=logging.getLogger('mldock')
+MLDOCK_CONFIG_NAME='mldock.json'
 
 @click.group()
 def local():
@@ -50,7 +53,7 @@ def build(obj, dir, no_cache, tag, stage):
     """Command to build container locally
     """
     mldock_manager = MLDockConfigManager(
-        filepath=os.path.join(dir, ".mldock.json")
+        filepath=os.path.join(dir, MLDOCK_CONFIG_NAME)
     )
     # get mldock_module_dir name
     mldock_config = mldock_manager.get_config()
@@ -156,7 +159,7 @@ def train(obj, dir, params, env_vars, tag, stage):
     Command to run training locally on localhost
     """
     mldock_manager = MLDockConfigManager(
-        filepath=os.path.join(dir, ".mldock.json")
+        filepath=os.path.join(dir, MLDOCK_CONFIG_NAME)
     )
     # get mldock_module_path name
     mldock_config = mldock_manager.get_config()
@@ -207,6 +210,12 @@ def train(obj, dir, params, env_vars, tag, stage):
         hyperparameters=hyperparameters,
         **project_env_vars
     )
+
+    config_manager = CliConfigureManager()
+    env_vars.update(
+        config_manager.local.get('environment')
+    )
+
     try:
         train_model(
             working_dir=dir,
@@ -255,7 +264,7 @@ def deploy(obj, dir, params, env_vars, tag, port, stage):
     Command to deploy ml container on localhost
     """
     mldock_manager = MLDockConfigManager(
-        filepath=os.path.join(dir, ".mldock.json")
+        filepath=os.path.join(dir, MLDOCK_CONFIG_NAME)
     )
     # get mldock_module_path name
     mldock_config = mldock_manager.get_config()
@@ -305,6 +314,12 @@ def deploy(obj, dir, params, env_vars, tag, port, stage):
         hyperparameters=mldock_config.get('hyperparameters', {}),
         **project_env_vars
     )
+
+    config_manager = CliConfigureManager()
+    env_vars.update(
+        config_manager.local.get('environment')
+    )
+
     try:
         logger.info("Started local deployment at {}...\n".format(port))
         deploy_model(
