@@ -13,6 +13,7 @@ from mldock.config_managers.container import \
 
 click.disable_unicode_literals_warning = True
 logger=logging.getLogger('mldock')
+MLDOCK_CONFIG_NAME='mldock.json'
 
 def reset_terminal():
     # os.system("clear")
@@ -70,7 +71,7 @@ def push(obj, dir, region, build, provider, no_cache, stage, tag):
     """
     reset_terminal()
     mldock_manager = MLDockConfigManager(
-        filepath=os.path.join(dir, ".mldock.json")
+        filepath=os.path.join(dir, MLDOCK_CONFIG_NAME)
     )
     # get mldock_module_dir name
     mldock_config = mldock_manager.get_config()
@@ -186,7 +187,7 @@ def pull(obj, dir, region, provider, no_cache, stage, tag):
     Command to pull docker container image from Image Registry
     """
     mldock_manager = MLDockConfigManager(
-        filepath=os.path.join(dir, ".mldock.json")
+        filepath=os.path.join(dir, MLDOCK_CONFIG_NAME)
     )
     # get mldock_module_dir name
     mldock_config = mldock_manager.get_config()
