@@ -3,16 +3,9 @@ import io
 import csv
 import logging
 import numpy as np
-
 from mldock.platform_helpers.mldock.errors import extract_stack_trace
-from mldock.platform_helpers import environment as mldock_environment
 from mldock.platform_helpers.mldock.model_service import base
-
-environment = mldock_environment.Environment(base_dir='/opt/ml')
-
-logging.basicConfig(level=logging.INFO)
-logger = logging.getLogger(None)
-logger.setLevel(logging.INFO)
+from src.container.assets import environment, logger
 
 class ModelService(base.ModelService):
     model = None
